@@ -48,18 +48,18 @@
 #'
 #' # Data set 1: 10 obs on 2 isos, 4 sources, with tefs and concdep
 #' data(geese_data_day1)
-#' simmr_1 <- with(
-#'   geese_data_day1,
-#'   simmr_load(
-#'     mixtures = mixtures,
-#'     source_names = source_names,
-#'     source_means = source_means,
-#'     source_sds = source_sds,
-#'     correction_means = correction_means,
-#'     correction_sds = correction_sds,
-#'     concentration_means = concentration_means
-#'   )
-#' )
+# simmr_1 <- with(
+#   geese_data_day1,
+#   simmr_load(
+#     mixtures = mixtures,
+#     source_names = source_names,
+#     source_means = source_means,
+#     source_sds = source_sds,
+#     correction_means = correction_means,
+#     correction_sds = correction_sds,
+#     concentration_means = concentration_means
+#   )
+# )
 #'
 #' # Plot
 #' plot(simmr_1)
@@ -217,19 +217,19 @@
 #'
 #' # Do this in raw data format - Note that there's quite a few mixtures!
 #' data(geese_data)
-# simmr_5 <- with(
-#' #  geese_data,
-#' #  simmr_load(
-#' #    mixtures = mixtures,
-#' #    source_names = source_names,
-#' #    source_means = source_means,
-#' #    source_sds = source_sds,
-#' #    correction_means = correction_means,
-#' #    correction_sds = correction_sds,
-#' #    concentration_means = concentration_means,
-#' #    group = groups
-#' #  )
-# )
+#' simmr_5 <- with(
+#'   geese_data,
+#'   simmr_load(
+#'     mixtures = mixtures,
+#'     source_names = source_names,
+#'     source_means = source_means,
+#'     source_sds = source_sds,
+#'     correction_means = correction_means,
+#'     correction_sds = correction_sds,
+#'     concentration_means = concentration_means,
+#'     group = groups
+#'   )
+#' )
 #'
 #' # Plot
 #' plot(simmr_5,
@@ -239,7 +239,7 @@
 #' )
 #'
 #' # Run MCMC for each group
-#' simmr_5_out <- simmr_mcmc(simmr_5)
+#' simmr_5_out <- simmr_ffvb(simmr_5)
 #'
 #' # Summarise output
 #' summary(simmr_5_out, type = "quantiles", group = 1)
@@ -276,13 +276,9 @@ simmr_ffvb <- function(simmr_in,
                          eps_0 = 0.1,
                          t_W = 50
                        )) {
-  #### make sure this has right file name
-  # Rcpp::sourceCpp("src/run_VB.cpp")
-
   # Throw a warning if less than 4 observations in a group - 1 is ok as it wil do a solo run
   if (min(table(simmr_in$group)) > 1 & min(table(simmr_in$group)) < 4) warning("At least 1 group has less than 4 observations - either put each observation in an individual group or use informative prior information")
 
-
   output <- vector("list", length = simmr_in$n_groups)
   names(output) <- levels(simmr_in$group)
   K <- simmr_in$n_sources
@@ -306,7 +302,6 @@ simmr_ffvb <- function(simmr_in,
 
   p_fun <- function(x) exp(x) / sum(exp(x))
 
-
   # Loop through all the groups
   for (i in 1:simmr_in$n_groups) {
     if (simmr_in$n_groups > 1) cat(paste("\nRunning for group", levels(simmr_in$group)[i], "\n\n"))
@@ -318,16 +313,16 @@ simmr_ffvb <- function(simmr_in,
     if (nrow(curr_mix) == 1) {
       cat("Only 1 mixture value, performing a simmr solo run...\n")
       solo <- TRUE
+      beta_prior = 100
     } else {
       solo <- FALSE
+      beta_prior = 0.001
     }
 
-
     n_tracers <- simmr_in$n_tracers
     n_sources <- simmr_in$n_sources
     s_names <- simmr_in$source_names
     K <- simmr_in$n_sources
-    S <- 100
     source_means <- simmr_in$source_means
     source_sds <- simmr_in$source_sds
     correction_means <- simmr_in$correction_means
@@ -335,13 +330,10 @@ simmr_ffvb <- function(simmr_in,
     concentration_means <- simmr_in$concentration_means
     y <- curr_mix
 
-
-
-
     lambdastart <- c(mu_a, rep(sigma_a, (((K * (K + 1)) / 2) + n_tracers * 2)))
 
     lambdares[, i] <- run_VB_cpp(
-      lambdastart, K, n_tracers, concentration_means,
+      lambdastart, K, n_tracers, beta_prior, concentration_means,
       source_means, correction_means, correction_sds,
       source_sds, y, ffvb_control$S,
       ffvb_control$P, ffvb_control$beta_1,
@@ -349,13 +341,9 @@ simmr_ffvb <- function(simmr_in,
       ffvb_control$eps_0, ffvb_control$t_W
     )
 
-
-
     thetares[(1 + n_output * (i - 1)):(n_output * i), ] <-
       sim_thetacpp(n_output, lambdares[, i], K, n_tracers)
 
-
-
     p <- t(apply(thetares[(1 + n_output * (i - 1)):(n_output * i), 1:K], 1, p_fun))
     sigma <- (1 / sqrt(thetares[
       (1 + n_output * (i - 1)):(n_output * i),
@@ -364,7 +352,6 @@ simmr_ffvb <- function(simmr_in,
 
     colnames(p) <- simmr_in$source_names
 
-
     sims.matrix <- cbind(
       p,
       sigma
@@ -391,9 +378,7 @@ simmr_ffvb <- function(simmr_in,
     )
   }
 
-  output_all <- vector("list")
-  output_all$input <- simmr_in
-  output_all$output <- mylist
+  output_all <- list(input = simmr_in, output = mylist)
 
   class(output_all) <- c("simmr_output", "ffvb")
 
