@@ -70,53 +70,53 @@
 #' # The data
 #' data(simmr_data_1)
 #' # Load into simmr
-#' simmr_tdf <- with(
-#'   simmr_data_1,
-#'   simmr_load(
-#'     mixtures = mixtures,
-#'     source_names = source_names,
-#'     source_means = source_means,
-#'     source_sds = source_sds,
-#'     correction_means = correction_means,
-#'     correction_sds = correction_sds,
-#'     concentration_means = concentration_means
-#'   )
-#' )
+# simmr_tdf <- with(
+#   simmr_data_1,
+#   simmr_load(
+#     mixtures = mixtures,
+#     source_names = source_names,
+#     source_means = source_means,
+#     source_sds = source_sds,
+#     correction_means = correction_means,
+#     correction_sds = correction_sds,
+#     concentration_means = concentration_means
+#   )
+# )
 #'
 #' # Plot
 #' plot(simmr_tdf)
 #'
 #' # MCMC run
-#' simmr_tdf_out <- simmr_mcmc_tdf(simmr_tdf,
-#'   p = matrix(
-#'     rep(
-#'       1 / simmr_tdf$n_sources,
-#'       simmr_tdf$n_sources
-#'     ),
-#'     ncol = simmr_tdf$n_sources,
-#'     nrow = simmr_tdf$n_obs,
-#'     byrow = TRUE
-#'   )
-#' )
-#'
+# simmr_tdf_out <- simmr_mcmc_tdf(simmr_tdf,
+#   p = matrix(
+#     rep(
+#       1 / simmr_tdf$n_sources,
+#       simmr_tdf$n_sources
+#     ),
+#     ncol = simmr_tdf$n_sources,
+#     nrow = simmr_tdf$n_obs,
+#     byrow = TRUE
+#   )
+# )
+
 #' # Summary
 #' summary(simmr_tdf_out, type = "diagnostics")
 #' summary(simmr_tdf_out, type = "quantiles")
 #'
 #' # Now put these corrections back into the model and check the
 #' # iso-space plots and dietary output
-#' simmr_tdf_2 <- with(
-#'   simmr_data_1,
-#'   simmr_load(
-#'     mixtures = mixtures,
-#'     source_names = source_names,
-#'     source_means = source_means,
-#'     source_sds = source_sds,
-#'     correction_means = simmr_tdf_out$c_mean_est,
-#'     correction_sds = simmr_tdf_out$c_sd_est,
-#'     concentration_means = concentration_means
-#'   )
-#' )
+# simmr_tdf_2 <- with(
+#   simmr_data_1,
+#   simmr_load(
+#     mixtures = mixtures,
+#     source_names = source_names,
+#     source_means = source_means,
+#     source_sds = source_sds,
+#     correction_means = simmr_tdf_out$c_mean_est,
+#     correction_sds = simmr_tdf_out$c_sd_est,
+#     concentration_means = concentration_means
+#   )
+# )
 #'
 #' # Plot with corrections now
 #' plot(simmr_tdf_2)
@@ -202,7 +202,7 @@ model {
   }
 
   # Prior on sigma
-  for(j in 1:J) { sigma[j] ~ dunif(0,sig_upp) }
+  for(j in 1:J) { sigma[j] ~ dgamma(0.001, sig_upp) }
 
   # Priors on c
   for (j in 1:J) {
